@@ -2,7 +2,7 @@ package Acme::PrettyCure::Girl::CureBlack;
 use utf8;
 use Any::Moose;
 
-with 'Acme::PrettyCure::Girl::Role';
+with qw/Acme::PrettyCure::Girl::Role Acme::PrettyCure::Girl::Role::Futari/;
 
 sub human_name   {'美墨なぎさ'}
 sub precure_name {'キュアブラック'}
@@ -25,14 +25,6 @@ before 'transform' => sub {
     die "ほのかがいないと変身できないメポ!" unless ref($buddy) =~ /CureWhite/;
 };
 
-after 'transform' => sub {
-    my ($self, $buddy) = @_;
-
-    unless ($buddy->is_precure) {
-        $buddy->transform($self);
-    }
-};
-
 no Any::Moose;
 __PACKAGE__->meta->make_immutable;
 
