@@ -2,7 +2,7 @@ package Acme::PrettyCure::Girl::CurePine;
 use utf8;
 use Any::Moose;
 
-with 'Acme::PrettyCure::Girl::Role';
+with qw/Acme::PrettyCure::Girl::Role Acme::PrettyCure::Girl::Role::Fresh/;
 
 sub human_name   {'山吹祈里'}
 sub precure_name {'キュアパイン'}
