@@ -1,13 +1,6 @@
 package Acme::PrettyCure::Girl::Role::Suite;
 use utf8;
-use Moo::Role;
-
-our $SUITE = [
-    '',
-    'ふたり',
-    '三人',
-    'みんな',
-];
+use Any::Moose '::Role';
 
 after 'transform' => sub {
     my ($self, @buddies) = @_;
@@ -24,7 +17,6 @@ after 'transform' => sub {
     }
 
     if ($first) {
-        $self->say('届け、' . $SUITE->[scalar(@buddies)] . 'の組曲!');
         $self->say('スイートプリキュア' . ('!' x (scalar(@buddies)+1)) );
     }
 };
